@@ -11,3 +11,8 @@ display_name <- function(x) {
     filenames
   }
 }
+
+filter_non_package_files <- function(x) {
+  filenames <- vapply(x, function(x) getSrcFilename(x$srcref, full.names = TRUE), character(1))
+  x[rex::re_matches(filenames, rex::rex(attr(x, "package")$path, "/"), "")]
+}
